#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_COSD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_COSD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/scalar/cosd.hpp>

#endif
